@@ -214,6 +214,7 @@ test_that("FEs work with multiple outcomes", {
 
 test_that("FEs work with missingness", {
 
+  skip_if_not_installed("sandwich")
   # In outcome
   datmiss <- dat
   datmiss$Y[5] <- NA
@@ -456,6 +457,9 @@ test_that("test matches stata absorb", {
 
 test_that("FEs give correct projected F-stats", {
 
+  skip_if_not_installed("lfe")
+  skip_on_cran()
+
   feo <- lfe::felm(Y ~ Z + X | B + B2, data = dat)
   sfeo <- lfe:::summary.felm(feo)
   sfeor <- lfe:::summary.felm(feo, robust = TRUE)
@@ -522,6 +526,8 @@ test_that("FEs give correct projected F-stats", {
 
 test_that("FE matches lm_robust with one block", {
 
+  skip_if_not_installed("sandwich")
+
   # In outcome
   datmiss <- dat
   datmiss$Y[5] <- NA
